@@ -741,3 +741,74 @@
     print $stderr_output;
 
     1;
+
+# Extending Decorating and Aliasing class objects
+
+    use strict;
+    use warnings;
+    use Extender;
+
+    # Declare the class with a namespace and version ###########################
+    class MyApp::Logger 1.0 {
+
+        # Constructor method
+        method new {
+            my $class = shift;
+            return bless {}, $class;
+        }
+
+        # Method with attributes
+        method log : Private {
+            my ($self, $message) = @_;
+            print STDERR $message;
+        }
+
+        # Public method to log an info message
+        method log_info {
+            my ($self, $message) = @_;
+            $self->log("[INFO] $message\n");
+        }
+
+        # Public method to log an error message
+        method log_error {
+            my ($self, $message) = @_;
+            $self->log("[ERROR] $message\n");
+        }
+
+    }
+
+    # Usage example
+    package main;
+
+    # Create a new Logger object ###############################################
+    my $logger = Extend(
+        MyApp::Logger->new(),
+        'Extender'
+    )
+        ->Extends(
+            'log_warn', sub {
+                my ($self, $message) = @_;
+                $self->log("[WARN] $message\n");
+            }
+        )
+        ->Alias(
+            'log_error', 'log_err'
+        )
+        ->Decorate(
+            'log_info', 
+            sub {
+                my ($self, $original, @args) = @_;
+                # Add extra behavior before and after
+                my $result = $original->($self, @args);
+                $self->log("[DECORATED] $args[0]\n");
+                return $result;
+            }
+        );
+
+    # Use the extended functionalities
+    $logger->log_info("This is an informational message.");
+    $logger->log_warn("This is a warning message.");
+    $logger->log_err("This is an error message.");
+
+    # Testing the decorated method
+    $logger->log_info("This message is decorated.");
